==> coopr.pyomo-2.1.tar.gz: coopr.pyomo-2.1/examples/pyomo/tutorials/table.py <==
#
# Imports
#
import sys
sys.path.append("../../..")
from coopr.pyomo import *
#pyomo.set_debugging()

##
## Using a Model
##
#
# Pyomo makes a fundamental distinction between an abstract model and a
# problem instance.  The Pyomo Model() class is used to manage the 
# declaration of model components (e.g. sets and variables), and to 
# generate a problem instance.
#
model = Model()

##
## Declaring Sets
##
#
# An unordered set of arbitrary objects
#
model.A = Set()
#
# An unordered set of numeric values
#
model.B = Set()
#
# A simple cross-product
#
model.C = model.A * model.B
#
# A simple cross-product loaded with a tabular data format
#
model.D = Set(within=model.A * model.B)
#
# A multiple cross-product
#
model.E = Set(within=model.A * model.B * model.A)

#
# An indexed set
# 
model.F = Set(model.A)
#
# An indexed set
# 
model.G = Set(model.A,model.B)
#
# A simple set
#
model.H = Set()
#
# A simple set
#
model.I = Set()
#
# A two-dimensional set
#
model.J = Set(dimen=2)

##
## Declaring Params
##
#
#
# A simple parameter
#
model.Z = Param()
#
# A single-dimension parameter
#
model.Y = Param(model.A)
#
# An example of initializing two single-dimension parameters together
#
model.X = Param(model.A)
model.W = Param(model.A)
#
# Initializing a parameter with two indices
#
model.U = Param(model.I,model.A)
model.T = Param(model.A,model.I)
#
# Initializing a parameter with missing data
#
model.S = Param(model.A)
#
# An example of initializing two single-dimension parameters together with
# an index set
#
model.R = Param(model.H, within=Reals)
model.Q = Param(model.H, within=Reals)
#
# An example of initializing parameters with a two-dimensional index set
#
model.P = Param(model.J, within=Reals)
model.PP = Param(model.J, within=Reals)
model.O = Param(model.J, within=Reals)
   
##
## Process an input file and confirm that we get appropriate 
## set instances.
##
#model.pprint()

data = ModelData(model)
data.add_table("tab/A.tab")
data.add_table("tab/B.tab")
data.add_table("tab/C.tab", set="C")
data.add_table("tab/D.tab", set="D", format="array")
data.add_table("tab/E.tab", set="E")
data.add_table("tab/I.tab")
data.add_table("tab/Z.tab", param="Z")
data.add_table("tab/Y.tab")
data.add_table("tab/XW.tab")
data.add_table("tab/T.tab", param="T", format="transposed_array")
data.add_table("tab/U.tab", param="U", format="array")
data.add_table("tab/S.tab")
data.add_table("tab/RQ.tab", index="H")
data.add_table("tab/PO.tab", index="J", param=("P","O"))
data.add_table("tab/PP.tab", param="PP")
data.read()

instance = model.create(data)
instance.pprint()

==> coopr.pyomo-2.2.tar.gz: coopr.pyomo-2.2/examples/pyomo/tutorials/table.py <==
#
# Imports
#
import sys
sys.path.append("../../..")
from coopr.pyomo import *
#pyomo.set_debugging()

##
## Using a Model
##
#
# Pyomo makes a fundamental distinction between an abstract model and a
# problem instance.  The Pyomo Model() class is used to manage the 
# declaration of model components (e.g. sets and variables), and to 
# generate a problem instance.
#
model = Model()

##
## Declaring Sets
##
#
# An unordered set of arbitrary objects
#
model.A = Set()
#
# An unordered set of numeric values
#
model.B = Set()
#
# A simple cross-product
#
model.C = model.A * model.B
#
# A simple cross-product loaded with a tabular data format
#
model.D = Set(within=model.A * model.B)
#
# A multiple cross-product
#
model.E = Set(within=model.A * model.B * model.A)

#
# An indexed set
# 
model.F = Set(model.A)
#
# An indexed set
# 
model.G = Set(model.A,model.B)
#
# A simple set
#
model.H = Set()
#
# A simple set
#
model.I = Set()
#
# A two-dimensional set
#
model.J = Set(dimen=2)

##
## Declaring Params
##
#
#
# A simple parameter
#
model.Z = Param()
#
# A single-dimension parameter
#
model.Y = Param(model.A)
#
# An example of initializing two single-dimension parameters together
#
model.X = Param(model.A)
model.W = Param(model.A)
#
# Initializing a parameter with two indices
#
model.U = Param(model.I,model.A)
model.T = Param(model.A,model.I)
#
# Initializing a parameter with missing data
#
model.S = Param(model.A)
#
# An example of initializing two single-dimension parameters together with
# an index set
#
model.R = Param(model.H, within=Reals)
model.Q = Param(model.H, within=Reals)
#
# An example of initializing parameters with a two-dimensional index set
#
model.P = Param(model.J, within=Reals)
model.PP = Param(model.J, within=Reals)
model.O = Param(model.J, within=Reals)
   
##
## Process an input file and confirm that we get appropriate 
## set instances.
##
#model.pprint()

data = ModelData(model=model)
data.add("tab/A.tab")
data.add("tab/B.tab")
data.add("tab/C.tab", set="C")
data.add("tab/D.tab", set="D", format="set_array")
data.add("tab/E.tab", set="E")
data.add("tab/I.tab")
data.add("tab/Z.tab", param="Z")
data.add("tab/Y.tab")
data.add("tab/XW.tab")
data.add("tab/T.tab", param="T", format="transposed_array")
data.add("tab/U.tab", param="U", format="array")
data.add("tab/S.tab")
data.add("tab/RQ.tab", index="H")
data.add("tab/PO.tab", index="J", param=("P","O"))
data.add("tab/PP.tab", param="PP")
data.read()

instance = model.create(data)
instance.pprint()
